Responsive enum

Inheritance
Available extensions

Values

xs → const Responsive
sm → const Responsive
md → const Responsive
lg → const Responsive
xl → const Responsive
xxl → const Responsive

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
maxWidth double
final
minWidth double
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getType(double? width) Responsive?

Available on Responsive, provided by the ResponsiveExtension extension

narrower(double? width) bool

Available on Responsive, provided by the ResponsiveExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wider(double? width) bool

Available on Responsive, provided by the ResponsiveExtension extension

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Responsive>
A constant List of the values in this enum, in order of their declaration.